models/preview_data library

Classes

PreviewData
A class that represents data obtained from the web resource (link preview).
PreviewDataImage
A utility class that forces image's width and height to be stored alongside the url.